summaryrefslogtreecommitdiffstats
path: root/src/entryview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/entryview.h')
-rw-r--r--src/entryview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/entryview.h b/src/entryview.h
index f6d4744..1a0ad76 100644
--- a/src/entryview.h
+++ b/src/entryview.h
@@ -39,10 +39,10 @@ public:
/**
* The EntryView shows a HTML representation of the data in the entry.
*
* @param tqparent TQWidget tqparent
* @param name TQObject name
*/
- EntryView(TQWidget* tqparent, const char* name=0);
+ EntryView(TQWidget* parent, const char* name=0);
/**
*/
virtual ~EntryView();
@@ -39,10 +39,10 @@ public:
* The EntryView shows a HTML representation of the data in the entry.
*
- * @param tqparent TQWidget tqparent
+ * @param parent TQWidget parent
* @param name TQObject name
*/